Optical methods
===============

Solcore includes several methods to calculate the optical properties of individual materials and of full stacks of layers. Some of them are built in, but it can also deal with externally provided data and, currently, it has also an interface to **S4** to perform rigorous couple wave analysis calculations.

.. toctree::
    :maxdepth: 2

    material_optics
    qw_absorption
    tmm
    rcwa
    other_methods

